/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtTest 1.0
import "../.."
import "../../../../Panel/Menus"
import Ubuntu.Components 0.1
import Unity.Test 0.1 as UT

Item {
    id: testIndicatorMenuWindowItem
    width: units.gu(9)
    height: units.gu(3)

    Rectangle {
        id: rectangle1
        anchors.fill: parent
        signal clicked

        MouseArea {
            anchors.fill: parent
            onClicked: rectangle1.clicked()
        }

        Rectangle {
            anchors.right: rectangle1.right
            anchors.left: rectangle1.horizontalCenter
            anchors.top: rectangle1.verticalCenter
            anchors.bottom: rectangle1.bottom
            color: "green"
            IndicatorMenuWindow {
                id: indicatorMenuWindow
                name: "TestIndicatorMenuWindow"
                anchors.fill: parent
            }
        }

        Rectangle {
            id: rectangle2
            color: "red"
            anchors.right: rectangle1.horizontalCenter
            anchors.left: rectangle1.left
            anchors.top: rectangle1.verticalCenter
            anchors.bottom: rectangle1.bottom
        }

        SignalSpy {
            id: clickedSpy
            target: rectangle1
            signalName: "clicked"
        }
    }

    UT.UnityTestCase {
        name: "IndicatorMenuWindow"
        when: windowShown

        function test_mouseEvent_data() {
            return [
                {tag: "invisible", shown: true, opacity: 1.0, mouseClicks: 0},
                {tag: "visible", shown: false, opacity: 0.0, mouseClicks: 1},
            ]
        }

        function test_mouseEvent(data) {
            indicatorMenuWindow.shown = data.shown
            tryCompare(indicatorMenuWindow, "opacity", data.opacity)

            clickedSpy.clear()
            mouseClick(indicatorMenuWindow, indicatorMenuWindow.width / 2,
                       indicatorMenuWindow.height / 2)
            compare(clickedSpy.count, data.mouseClicks,
                  "Check for Mouse event eating by indicatorMenuWindow failed")
        }
    }
}
